import Message from "./Message.js";
import b4a from "b4a";

class IconMessage extends Message {
    /**
     * @description Creates a new icon message.
     * @since 1.0
     * @author MiTask
     * @constructor
     * @param {String} peerName Peer username
     * @param {String} peerAvatar Peer avatar URL
     * @param {Number} timestamp UNIX Timestamp
     */
    constructor(peerName, peerAvatar, timestamp) {
        super("icon", peerName, peerAvatar, null, timestamp);
    }

    /**
     * @description Creates a new icon message instance.
     * @since 1.0
     * @author MiTask
     * @param {Client} bot Bot Client class
     * @param {String} avatarBuffer Bot Avatar buffer
     * @returns {IconMessage} IconMessage instance
     */
    static new(bot, avatarBuffer) {
        return new IconMessage(bot.botName, b4a.toString(avatarBuffer, 'base64'), Date.now());
    }
}

export default IconMessage;
